@@ -20,6 +20,6 @@ def write_vector(vec: List[np.ndarray], outfile: PathLike) -> None:
     """
     wfile = open(outfile, 'a')
     for (idx, line) in enumerate(vec[0]):
-        wfile.write(vec[0][idx] + ' ' + vec[1][idx] + ' ' + vec[2][idx] + ' ' + vec[3][idx] + ' ' + vec[4][idx] + ' ' +
-                    vec[5][idx] + ' ' + vec[6][idx] + '\n')
+        wfile.write(str(vec[0][idx]) + ' ' + str(vec[1][idx]) + ' ' + str(vec[2][idx]) + ' ' + str(vec[3][idx]) +
+                    ' ' + str(vec[4][idx]) + ' ' + str(vec[5][idx]) + ' ' + str(vec[6][idx]) + '\n')
     wfile.close()
\ No newline at end of file
